Uni–Form

#

This is an example form demonstrating all of the units offered by Uni–Form, along with suggested message handling, form actions and style.

## Default Style

Author: Dragan Babić see more styles →

### Ooops! Your error message title

1. Error number one
2. Error number two

Looks like everything went OK! Yay!

### Default Form Field Layout

* Small text input

This is a form hint.

* Medium text input

This is a form hint.

* Large text input

This is a form hint.

* Autosized text input

This is a form hint.

* Textarea

This is a form hint.

Select

This is a form hint.

File upload

This is a form hint.

* Multifield with select boxes

- Label
- Label
- Label

This is a form hint.

* Alternate multifield Layout

- Label
- Label
- Label

This is a form hint.

* Multifield with text inputs

- Label
- Label
- Label

This is a form hint.

* Multifield with radios

- Option
- Option

This is a form hint.

- I have read and agree with the terms and conditions

This is a form hint.

### Alternate Form Fields Layout

* Small text input

This is a form hint.

* Medium text input

This is a form hint.

* Large text input

This is a form hint.

* Autosized text input

This is a form hint.

* Textarea

This is a form hint.

Select

This is a form hint.

File upload

This is a form hint.

* Multifield with select boxes

- Label
- Label
- Label

This is a form hint.

* Alternate multifield Layout

- Label
- Label
- Label

This is a form hint.

* Multifield with text inputs

- Label
- Label
- Label

This is a form hint.

* Multifield with radios

- Option
- Option

This is a form hint.

- I have read and agree with the terms and conditions

This is a form hint.

## Change style

- Default
- Blue
- Dark